@@ -56,7 +56,7 @@ def do_sync_full_table(conn_config, stream, state, desired_columns, md_map):
     """
     LOGGER.info("Stream %s is using full_table replication", stream['tap_stream_id'])
     sync_common.send_schema_message(stream, [])
-    attemp = 0
+    attempt = 0
     while True:
         try:
             if md_map.get((), {}).get('is-view'):
@@ -66,10 +66,10 @@ def do_sync_full_table(conn_config, stream, state, desired_columns, md_map):
             return state
         except Exception as e:
             LOGGER.warn("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
-            if attemp > post_db.TRY_NUMBER:
+            if attempt > post_db.TRY_NUMBER:
                 raise e
             else:
-                attemp = attemp + 1
+                attempt = attempt + 1
 
 
 # Possible state keys: replication_key, replication_key_value, version
@@ -82,18 +82,26 @@ def do_sync_incremental(conn_config, stream, state, desired_columns, md_map):
                 stream['tap_stream_id'],
                 replication_key)
 
-    stream_state = state.get('bookmarks', {}).get(stream['tap_stream_id'])
-    illegal_bk_keys = set(stream_state.keys()).difference(
-        {'replication_key', 'replication_key_value', 'version', 'last_replication_method'})
-    if len(illegal_bk_keys) != 0:
-        raise Exception("invalid keys found in state: {}".format(illegal_bk_keys))
+    attempt = 0
+    while True:
+        try:
+            stream_state = state.get('bookmarks', {}).get(stream['tap_stream_id'])
+            illegal_bk_keys = set(stream_state.keys()).difference(
+                {'replication_key', 'replication_key_value', 'version', 'last_replication_method'})
+            if len(illegal_bk_keys) != 0:
+                raise Exception("invalid keys found in state: {}".format(illegal_bk_keys))
 
-    state = singer.write_bookmark(state, stream['tap_stream_id'], 'replication_key', replication_key)
+            state = singer.write_bookmark(state, stream['tap_stream_id'], 'replication_key', replication_key)
 
-    sync_common.send_schema_message(stream, [replication_key])
-    state = incremental.sync_table(conn_config, stream, state, desired_columns, md_map)
-
-    return state
+            sync_common.send_schema_message(stream, [replication_key])
+            state = incremental.sync_table(conn_config, stream, state, desired_columns, md_map)
+            return state
+        except Exception as e:
+            LOGGER.warn("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
+            if attempt > post_db.TRY_NUMBER:
+                raise e
+            else:
+                attempt = attempt + 1
 
 
 def sync_method_for_streams(streams, state, default_replication_method):
